@@ -227,8 +227,25 @@ def test_2391():
             field_field_value = field.on_state()
             field.update()
 
-# def test_deletewidget():
-#     pdf = fitz.open(filename)
-#     page = pdf[0]
-#     field = page.first_widget
-#     page.delete_widget(field)
+def test_3216():
+    document = fitz.open(filename)
+    for page in document:
+        while 1:
+            w = page.first_widget
+            print(f'{w=}')
+            if not w:
+                break
+            page.delete_widget(w)
+
+
+def test_add_widget():
+    doc = fitz.open()
+    page = doc.new_page()
+    w = fitz.Widget()
+    w.field_type = fitz.PDF_WIDGET_TYPE_BUTTON
+    w.rect = fitz.Rect(5, 5, 20, 20)
+    w.field_flags = fitz.PDF_BTN_FIELD_IS_PUSHBUTTON
+    w.field_name = "button"
+    w.fill_color = (0, 0, 1)
+    w.script = "app.alert('Hello, PDF!');"
+    page.add_widget(w)
